Mnemosyne.Graph.Edge (mnemosyne v0.1.6)

Copy Markdown View Source

Defines the typed edge categories used in the knowledge graph.

Summary

Functions

Returns a map with all edge types initialized to empty MapSets.

Returns all valid edge type atoms.

Types

edge_type()

@type edge_type() :: :membership | :hierarchical | :provenance | :sibling

Functions

empty_links()

@spec empty_links() :: %{required(edge_type()) => MapSet.t()}

Returns a map with all edge types initialized to empty MapSets.

types()

@spec types() :: [edge_type()]

Returns all valid edge type atoms.