Defines the typed edge categories used in the knowledge graph.
Summary
Functions
Returns a map with all edge types initialized to empty MapSets.
Returns all valid edge type atoms.
Defines the typed edge categories used in the knowledge graph.
Returns a map with all edge types initialized to empty MapSets.
Returns all valid edge type atoms.